%ifarch %{ix86}
%define efiarch	ia32
%endif
%ifarch x86_64
%define efiarch	x64
%endif

%define debug_package %{nil}

Name:		refind
Version:	0.13.3.1
Release:	%mkrel 2
Summary:	EFI boot manager
License:	GPLv3
Group:		System/Boot and Init
URL:		https://www.rodsbooks.com/refind/
Source0:	https://sourceforge.net/projects/refind/files/%version/refind-src-%version.tar.gz
# Replace old Mageia icon with current version
Source1:	os_mageia.png
# Use Mageia dark blue background
Source2:	dark-blue-banner.png
# Fix ESP mount point and GNU EFI library paths
Patch0: 	mga-system-path-fixes.patch
# Add --nvramonly option to refind-install
Patch1: 	install-nvram-only.patch
# Support 32-bit EFI on 64-bit O/S (and vice versa)
Patch2:		detect-efi-size.patch
# Change default banner
Patch3:		use-dark-blue-banner.patch
# Fix compatibility with ext4 filesystems created by e2fsprogs >= 1.47.0
Patch4:		ignore-ext4-metadata_csum_seed-feature.patch

ExclusiveArch:  %{ix86} x86_64
BuildRequires:	gnu-efi-devel
Provides:	bootloader
Requires:	efibootmgr

%description

A graphical boot manager for EFI- and UEFI-based computers, such as all
Intel-based Macs and recent (most 2011 and later) PCs. rEFInd presents a
boot menu showing all the EFI boot loaders on the EFI-accessible
partitions, and optionally BIOS-bootable partitions on Macs and BIOS boot
entries on UEFI PCs with CSMs. EFI-compatible OSes, including Linux,
provide boot loaders that rEFInd can detect and launch. rEFInd can launch
Linux EFI boot loaders such as ELILO, GRUB Legacy, GRUB 2, and 3.3.0 and
later kernels with EFI stub support. EFI file system drivers for ext2/3/4fs,
ReiserFS, Btrfs, NTFS, HFS+, and ISO-9660 enable rEFInd to read boot
loaders from these file systems, too. rEFInd's ability to detect boot
loaders at run time makes it very easy to use, particularly when paired with
Linux kernels that provide EFI stub support.

%prep
%autosetup -p1
cp %{SOURCE1} %{SOURCE2} icons/

%build
make LIBDIR=%{_libdir} gnuefi
make LIBDIR=%{_libdir} fs_gnuefi

%install
mkdir -p %{buildroot}%{_datadir}/%{name}/refind/

# Copy the rEFInd binaries (rEFInd proper and drivers)
install -Dp -m0644 refind/refind*.efi %{buildroot}%{_datadir}/%{name}/refind/
mkdir -p %{buildroot}%{_datadir}/%{name}/refind/drivers_%{efiarch}
cp -a drivers_%{efiarch}/* %{buildroot}%{_datadir}/%{name}/refind/drivers_%{efiarch}/
mkdir -p %{buildroot}%{_datadir}/%{name}/refind/tools_%{efiarch}
install -Dp -m0644 gptsync/gptsync_%{efiarch}.efi %{buildroot}%{_datadir}/%{name}/refind/tools_%{efiarch}/gptsync_%{efiarch}.efi

# Copy configuration and support files
install -Dp -m0644 refind.conf-sample %{buildroot}%{_datadir}/%{name}/refind/
cp -a icons %{buildroot}%{_datadir}/%{name}/refind/
rm -rf %{buildroot}%{_datadir}/%{name}/refind/icons/svg
install -Dp -m0755 refind-install %{buildroot}%{_datadir}/%{name}/

# Copy man pages
mkdir -p %{buildroot}%{_mandir}/man8
install -Dp -m0644 docs/man/mvrefind.8 %{buildroot}%{_mandir}/man8
install -Dp -m0644 docs/man/mkrlconf.8 %{buildroot}%{_mandir}/man8
install -Dp -m0644 docs/man/refind-install.8 %{buildroot}%{_mandir}/man8
install -Dp -m0644 docs/man/refind-mkdefault.8 %{buildroot}%{_mandir}/man8

# Copy scripts
mkdir -p %{buildroot}%{_sbindir}
install -Dp -m0755 mkrlconf %{buildroot}%{_sbindir}/
install -Dp -m0755 mvrefind %{buildroot}%{_sbindir}/
install -Dp -m0755 refind-mkdefault %{buildroot}%{_sbindir}/
ln -sr %{buildroot}%{_datadir}/%{name}/refind-install %{buildroot}%{_sbindir}

# Copy banners and fonts
cp -a banners %{buildroot}%{_datadir}/%{name}/
cp -a fonts %{buildroot}%{_datadir}/%{name}/

# Create sysconfig file
mkdir -p %{buildroot}%{_sysconfdir}/sysconfig
echo "REFIND_BANNER=%{_datadir}/%{name}/refind/icons/dark-blue-banner.png"    > %{buildroot}%{_sysconfdir}/sysconfig/refind
echo "MAGEIA_THEME=%{_datadir}/mga/backgrounds/Mageia-Default-3840x2160.png" >> %{buildroot}%{_sysconfdir}/sysconfig/refind

# Create version file and urpmi README file
echo %{version} > VERSION
echo "Version %{version} of the rEFInd boot manager is now available."   > README.urpmi
echo "To install it in the ESP, either use drakboot or, as root user,"  >> README.urpmi
echo "execute the command '/sbin/refind-install'."                      >> README.urpmi
echo "If you are having no problems with booting your system, there is" >> README.urpmi
echo "no need to install this update in the ESP."                       >> README.urpmi

%files
%doc NEWS.txt COPYING.txt LICENSE.txt README.txt CREDITS.txt docs/Styles docs/refind
%doc VERSION README.urpmi
%{_sbindir}/mkrlconf
%{_sbindir}/mvrefind
%{_sbindir}/refind-install
%{_sbindir}/refind-mkdefault
%{_datadir}/%{name}
%{_mandir}/man8/*
%config %{_sysconfdir}/sysconfig/refind


%changelog
* Sat Feb 11 2023 martinw <martinw> 0.13.3.1-2.mga9
+ Revision: 1940556
- fix compatibility with ext4 filesystems created by e2fsprogs >= 1.47.0

* Tue Aug 09 2022 martinw <martinw> 0.13.3.1-1.mga9
+ Revision: 1876381
- add support for background selection in drakboot (mga#28073)
- new version 0.13.3.1
  o drop upstreamed patches
  o rebase other patches
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Wed Jan 13 2021 martinw <martinw> 0.12.0-2.mga8
+ Revision: 1671569
- fix early-exit bug in refind-install script
- set default background colour to Mageia dark blue (mga#28073)

* Tue May 12 2020 martinw <martinw> 0.12.0-1.mga8
+ Revision: 1583319
- new version 0.12.0
- fix build with GCC 10

* Fri Feb 14 2020 umeabot <umeabot> 0.11.4-2.mga8
+ Revision: 1521258
- Mageia 8 Mass Rebuild

* Mon Dec 17 2018 martinw <martinw> 0.11.4-1.mga7
+ Revision: 1342446
- new version 0.11.4
- support 32-bit UEFI on 64-bit O/S

* Thu Sep 13 2018 martinw <martinw> 0.11.2-3.mga7
+ Revision: 1258909
- don't automatically install in ESP
  o the user may want to specify different install options

* Tue Sep 11 2018 martinw <martinw> 0.11.2-2.mga7
+ Revision: 1258466
- add provides:bootloader

* Tue Sep 11 2018 martinw <martinw> 0.11.2-1.mga7
+ Revision: 1258338
- imported package refind

